{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E\N{U+060c} d MMM\N{U+060c} y G",
    GyMMMd => "d MMM\N{U+060c} y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E\N{U+060c} d/M",
    MMM => "LLL",
    MMMEd => "E\N{U+060c} d MMM",
    "MMMMW-count-one" => "MMMM \N{U+06a9}\N{U+0627} \N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} W",
    "MMMMW-count-other" => "MMMM \N{U+06a9}\N{U+0627} \N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1} W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E\N{U+060c} d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E\N{U+060c} d MMM\N{U+060c} y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM\N{U+060c} y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y \N{U+06a9}\N{U+0627} w \N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "yw-count-other" => "Y \N{U+06a9}\N{U+0627} w \N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
  },
  code => "ur-PK",
  date_format_full => "EEEE\N{U+060c} d MMMM\N{U+060c} y",
  date_format_long => "d MMMM\N{U+060c} y",
  date_format_medium => "d MMM\N{U+060c} y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  era_abbreviated => [
    "\N{U+0642}\N{U+0628}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+06cc}\N{U+062d}",
    "\N{U+0639}\N{U+06cc}\N{U+0633}\N{U+0648}\N{U+06cc}",
  ],
  era_narrow => [
    "\N{U+0642}\N{U+0628}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+06cc}\N{U+062d}",
    "\N{U+0639}\N{U+06cc}\N{U+0633}\N{U+0648}\N{U+06cc}",
  ],
  era_wide => [
    "\N{U+0642}\N{U+0628}\N{U+0644} \N{U+0645}\N{U+0633}\N{U+06cc}\N{U+062d}",
    "\N{U+0639}\N{U+06cc}\N{U+0633}\N{U+0648}\N{U+06cc}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "\N{U+0648} %H:%M:%S %Z \N{U+062a} %d %B %Y",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "\N{U+0648} %H:%M:%S \N{U+062a} %d %B %Y",
  glibc_time_12_format => "%P %I:%M:%S",
  glibc_time_format => "%H:%M:%S",
  language => "Urdu",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Urdu Pakistan",
  native_language => "\N{U+0627}\N{U+0631}\N{U+062f}\N{U+0648}",
  native_name => "\N{U+0627}\N{U+0631}\N{U+062f}\N{U+0648} \N{U+067e}\N{U+0627}\N{U+06a9}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646}",
  native_script => undef,
  native_territory => "\N{U+067e}\N{U+0627}\N{U+06a9}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+067e}\N{U+06c1}\N{U+0644}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062f}\N{U+0648}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062a}\N{U+06cc}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+0647}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+067e}\N{U+06c1}\N{U+0644}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062f}\N{U+0648}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062a}\N{U+06cc}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+0647}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+067e}\N{U+06c1}\N{U+0644}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062f}\N{U+0648}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062a}\N{U+06cc}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+0647}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+067e}\N{U+06c1}\N{U+0644}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062f}\N{U+0648}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+062a}\N{U+06cc}\N{U+0633}\N{U+0631}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+0647}\N{U+06cc} \N{U+0633}\N{U+06c1} \N{U+0645}\N{U+0627}\N{U+06c1}\N{U+06cc}",
  ],
  script => undef,
  territory => "Pakistan",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 38,
}
